@@ -1,20 +1,22 @@
 import xml.etree.ElementTree as etree
 from pathlib import Path
-from typing import List, Union, cast
 
 from pytiled_parser.properties import Properties, Property
 from pytiled_parser.util import parse_color
 
 
 def parse(raw_properties: etree.Element) -> Properties:
-
     final: Properties = {}
     value: Property
 
     for raw_property in raw_properties.findall("property"):
-
         type_ = raw_property.attrib.get("type")
-        value_ = raw_property.attrib.get("value")
+
+        if "value" not in raw_property.attrib:
+            continue
+
+        value_ = raw_property.attrib["value"]
+
         if type_ == "file":
             value = Path(value_)
         elif type_ == "color":
